@@ -129,7 +129,7 @@ namespace Spotify
              * @return Error
              */
             Spotify::Error getAlbumCover( Spotify::Album* album );
-            Spotify::Error getAlbumCover( Spotify::Track* track );
+            //Spotify::Error getAlbumCover( Spotify::Track* track );
 
             /**
              * Get the collection of playlists.
